@@ -41,7 +41,7 @@ class PeopleStock(AbstractMugshotStock):
         self.__person_items = {}
 
         self.__slideout = None
-        self.__slideout_item = None
+        self.__current_slideout = None
         self.__last_slideout_event_time = None
         self.__in_slideout_close_event = False
 
@@ -57,7 +57,7 @@ class PeopleStock(AbstractMugshotStock):
             
         ## add a new search provider (FIXME never gets disabled)
         search.enable_search_provider('people',
-                                      lambda: PeopleSearchProvider(self.__tracker))
+                                      lambda: PeopleSearchProvider(self.__tracker, self))
 
         self.__accounts_config = os.path.expanduser('~/.purple/accounts.xml')
         VfsMonitor('file://' + self.__accounts_config, gnomevfs.MONITOR_FILE,
@@ -143,19 +143,21 @@ class PeopleStock(AbstractMugshotStock):
     def __handle_item_pressed(self, item, event):
         self.__in_slideout_close_event = self.__last_slideout_event_time == gtk.get_current_event_time()
         
-    def __handle_item_activated(self, item):
-        same_item = self.__slideout_item == item
+    def __slideout_item(self, item, y_fixup=0):
+        # y_fixup is a number to be added to the the current position of the item
+        # to determine where it will be after asynchronous scrolling occurs
+        same_item = self.__current_slideout == item
         if same_item and self.__in_slideout_close_event:
-            self.__slideout_item = None  
+            self.__current_slideout = None  
             self.__in_slideout_close_event = False
             return True
 
         self.__in_slideout_close_event = False
 
         self.__slideout = bigboard.slideout.ThemedSlideout()
-        self.__slideout_item = item
-        coords = item.get_screen_coords()
-
+        self.__current_slideout = item
+        item_x, item_y = item.get_screen_coords()
+        
         p = ProfileItem(item.get_person(),
                         themed=True)
         
@@ -164,13 +166,36 @@ class PeopleStock(AbstractMugshotStock):
         self.__slideout.connect("close", self.__close_slideout)
         try:
             success = False
-            success = self.__slideout.slideout_from(coords[0] + item.get_allocation()[0] + 4, coords[1])
+            success = self.__slideout.slideout_from(item_x + item.get_allocation()[0] + 4, item_y + y_fixup)
         finally:
             if not success:
                 self.__close_slideout()
 
         return success
 
+    def __handle_item_activated(self, item):
+        self.__slideout_item(item)
+
+    def slideout_person(self, person):
+        try:
+            item = self.__person_items[person]
+        except KeyError:
+            return
+
+        # Compute the position of the item relative to it's parent item; a bit
+        # hacky, but I can't think of an easier way to do it
+        _, box_y = self.__person_box.get_context().translate_to_widget(self.__person_box)
+        _, item_y = item.get_context().translate_to_widget(item)
+        box_relative_y = item_y - box_y
+
+        # Now scroll the scroll ribbon so that the item is visible; since this
+        # is asynchronous, we get a "fixup" indicating the number of pixels that
+        # the item will eventually move
+        _, item_height = item.get_allocation()
+        y_fixup = self.__scroll_box.scroll_range_visible(box_relative_y, item_height)
+        
+        self.__slideout_item(item, y_fixup)
+
     def __on_more_button(self):
         if self.__people_browser is None:
             self.__people_browser = peoplebrowser.PeopleBrowser(self)
@@ -207,29 +232,27 @@ class PeopleSearchResult(search.SearchResult):
 
     def _on_activated(self):
         """Action when user has activated the result"""
-        if self.__person.user:
-            libbig.show_url(self.__person.user.homeUrl)
-        else:
-            ### FIXME - what should we do here? open an IM conversation?
-            ### or scroll to and pop out the user in the people stock?
-            pass
+        self.get_provider().get_stock().slideout_person(self.__person)
 
 class PeopleSearchProvider(search.SearchProvider):    
-    def __init__(self, tracker):
+    def __init__(self, tracker, stock):
         super(PeopleSearchProvider, self).__init__()
         self.__tracker = tracker
+        self.__stock = stock
 
     def get_heading(self):
         return "People"
-        
+
     def perform_search(self, query, consumer):
+        query = query.lower()
+        
         results = []
         
         for p in self.__tracker.people:
             #_logger.debug("person: " + str(p))
 
             matched = False
-            if query in p.display_name:
+            if query in p.display_name.lower():
                 matched = True
 
             for email in p.emails:
@@ -237,15 +260,22 @@ class PeopleSearchProvider(search.SearchProvider):
                     matched = True
                     break
                 
-            if not matched:
-                if query in p.aims:
+            for aim in p.aims:
+                if query in aim.lower():
                     matched = True
+                    break
                 
-                if query in p.xmpps:
+            for xmpp in p.xmpps:
+                if query in xmpp.lower():
                     matched = True
+                    break
 
             if matched:
                 results.append(PeopleSearchResult(self, p))
 
         if len(results) > 0:
             consumer.add_results(results)
+
+    def get_stock(self):
+        return self.__stock
+        
