@@ -416,9 +416,14 @@ class SelfStock(AbstractMugshotStock):
         _logger.debug("photoUrl: %s", myself.photoUrl)
         self._photo.set_url(myself.photoUrl)
         self._name.set_property("text", myself.name)
-        
+
+        try:
+            loved_accounts = myself.lovedAccounts
+        except AttributeError:
+            loved_accounts = []
+
         self._whereim_box.remove_all()
-        for acct in myself.lovedAccounts:
+        for acct in loved_accounts:
             icon = ExternalAccountIcon(acct)
             _logger.debug("appending external account %s", acct.accountType)
             self._whereim_box.append(icon)
